@@ -10,9 +10,10 @@ from config import __version__
 
 new_element = None
 
+# TODO: сделать обработку ref
+
 
 def __dump_json__(file_path, json):
-    # TODO: перейти на использование этого метода во всех методах
     with open(file_path, 'w') as file:
         file.write(json_dump(json, indent=4))
 
@@ -41,8 +42,7 @@ def __update_add_command__(params, template):
         __parse_element__(template['properties'][i], i, new_element)
         config[i] = new_element[i]
 
-    with open(params.config_file, 'w') as file_config:
-        file_config.write(json_dump(config, indent=4))
+    __dump_json__(params.config_file, config)
     print(f"{'Элемент добавлен' if len(params.elements) == 1 else 'Элементы добавлены'}")
 
 
@@ -121,8 +121,7 @@ def create_command(params):
             message += f"{i}, "
         print(message[:-2])
         return
-
-    if path_exists(params.config_file.name):
+    if path_exists(params.config_file):
         print('Файл конфигурации уже существует, перезаписать его? (y/n)')
         answer = input()
         if answer.lower() != "yes" and answer.lower() != 'y':
@@ -143,7 +142,7 @@ def create_command(params):
             __parse_element__(template['properties'][i], i, new_element)
             default_config[i] = new_element[i]
 
-    params.config_file.write(json_dump(default_config, indent=4))
+    __dump_json__(params.config_file, default_config)
     print('Конфигурация создана')
 
 
@@ -188,8 +187,7 @@ def create_parse():
                                        description="Команды, которые должны быть в качестве первого параметра %(prog)s")
 
     create_command_parser = subparsers.add_parser("create", add_help=False)
-    # TODO: изменить тип
-    create_command_parser.add_argument('config_file', type=argparse.FileType(mode='w'))
+    create_command_parser.add_argument('config_file')
     create_command_parser.add_argument('-e', '--elements', nargs='+', help="Элементы, которые нужно добавить в конфиг. "
                                                                            "Для работы этого параметра требуется "
                                                                            "указать переменную окружения "
